#
# spec file for package kpackage
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang
%define _tar_path 5.45
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %global _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
Name:           kpackage
Version:        5.45.0
Release:        lp150.1.1
%define kf5_version %{version}
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  karchive-devel >= %{_kf5_bugfix_version}
BuildRequires:  kconfig-devel >= %{_kf5_bugfix_version}
BuildRequires:  kcoreaddons-devel >= %{_kf5_bugfix_version}
BuildRequires:  kdoctools-devel >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel >= %{_kf5_bugfix_version}
BuildRequires:  cmake(Qt5Core) >= 5.6.0
BuildRequires:  cmake(Qt5Test) >= 5.6.0
%if %{with lang}
Recommends:     %{name}-lang
%endif
Summary:        Manage user installable packages of non-binary assets
License:        LGPL-2.1-or-later
Group:          System/GUI/KDE
Url:            http://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This framework lets applications to manage user installable packages of non-binary assets.

%package devel
Summary:        Manage user installable packages of non-binary assets
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules
Requires:       kcoreaddons-devel >= %{_kf5_bugfix_version}

%description devel
This framework lets applications to manage user installable packages of non-binary assets.
Development files.

%lang_package
%prep
%setup -q

%build
  %cmake_kf5 -d build -- -DSYSCONF_INSTALL_DIR=%{_kf5_sysconfdir}
  %make_jobs

%install
  %kf5_makeinstall -C build

%if %{with lang}
%find_lang %{name} --with-man --all-name
%endif

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%if %{with lang}
%files lang -f %{name}.lang
%endif

%files
%defattr(-,root,root)
%doc COPYING* README*
%{_kf5_bindir}/kpackagetool*
%{_kf5_libdir}/libKF5Package.so.*
%dir %{_kf5_servicetypesdir}
%{_kf5_servicetypesdir}/kpackage-packagestructure.desktop
%{_kf5_servicetypesdir}/kpackage-generic.desktop
%{_kf5_servicetypesdir}/kpackage-genericqml.desktop
%doc %lang(en) %{_kf5_mandir}/*/kpackagetool*
%{_kf5_debugdir}/*.categories

%files devel
%defattr(-,root,root)
%{_kf5_libdir}/libKF5Package.so
%{_kf5_libdir}/cmake/KF5Package/
%{_kf5_includedir}/

%changelog
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Try to fix the FreeBSD build.
  * Use Qt5::rcc instead of looking for the executable.
  * Use NO_DEFAULT_PATH to ensure the right command is picked up
  * Look also for prefixed rcc executables
  * set component for correct qrc generation
  * regenerate qrc on every build
  * Don't create dependency loop
  * Fix the rcc binary package generation
  * set(component ${component})
  * Fix rcc packages generation
  * Generate the rcc file every time, at install time
  * Use ecm_setup_qtplugin_macro_names
  * remove the rcc before generating
  * Make org.kde. components include a donate URL
  * Remove not necessary QtCore and co
  * Mark kpackage_install_package undeprecated for plasma_install_package
  * autotest: improve error reporting on failure
* Tue Mar 13 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Help automoc to find metadata JSON files referenced in the code
* Tue Feb 13 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Fix typo
  * Prevent cmake 3.10+ warning with moc & K_EXPORT_KPACKAGE_PACKAGE_WITH_JSON
  * invalidate the runtime cache on install
  * adjust relative directory
  * use configure_file instead of install
  * use QByteArrayLiteral
  * create the needed directory
  * experimental support for rcc files loading in kpackage
  * Use qCDebug
  * compile against Qt 5.7
  * Fix up package indexing and add runtime caching
  * new KPackage::fileUrl() method
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Fix trivial clazy warnings
  * Properly do strings in the kpackage framework
  * Don't try to generate metadata.json if there's no metadata.desktop
  * fix kpluginindex caching
  * Improve error output
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * use the non installed service files
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * kpackage: bundle a copy of servicetypes/kpackage-generic.desktop
  * kpackagetool: bundle a copy of servicetypes/kpackage-generic.desktop
  * autotest: adapt for ECM 5.38 setting CMAKE_RUNTIME_OUTPUT_DIRECTORY to bin
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * refactor kpackagetool away from stringy options
  * autotests: fix running tests in parallel
  * kpackagetool: fix memory leak detected by LeakSanitizer
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * kpackagetool can now write appstream data to a file
  * assert the testpackage appstream data validates
  * adopt new KAboutLicense::spdx
  * do not stderr that NoDisplay is set
  * API dox: use @param for normal parameter listing, not @arg
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Added kpackage-genericqml.desktop
  * tests: forgot to use LINK_LIBRARIES for ecm_add_test
  * cmake: use ecm_add_test more
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * API dox: NULL pointer -> null pointer
  * API dox: Use doxygen notation to have comments used
  * API dox: note CamelCase includes by @class tag with more classes
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Fix spelling in documentation.
  * fix include path in KF5PackageMacros.cmake https://phabricator.kde.org/D5615
  * Ignore warnings during appdata generation (kde#378529)
- Remove patches, now upstream:
  * 0001-Ignore-warnings-during-appdata-generation.patch
- Use %%find_lang --with-man --all-name
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * build autotests as regular executables
  * Upgrade KF5 version to 5.33.0.
* Fri Apr  7 2017 fabian@ritter-vogt.de
- Add patch to allow appdata installation even with warnings:
  * 0001-Ignore-warnings-during-appdata-generation.patch
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * finish support for opening compressed packages
  * Upgrade KF5 version to 5.32.0.
  * Upgrade Qt5 version requirement to 5.6.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Thu Jan 19 2017 fabian@ritter-vogt.de
- Update to 5.30.0
  * [PackageLoader] Don't access invalid KPluginMetadata (bug 374541)
  * fix description for option -t in man page
  * Improve error message
  * Fix the help message for --type
  * Improve installation process of KPackage bundles
  * Install a kpackage-generic.desktop file
  * Exclude qmlc files from installation
  * Don't list separately plasmoids from metadata.desktop and .json
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.29.1
  * Fix cmake failure when two packages with different type have same id
  * Additional fix for packages with different types but same ids
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Keep installing metadata.desktop (kde#372594)
  * Manually load metadata if absolute path is passed
  * Fix potential failure if package is not appstream compatible
  * Let KPackage know about X-Plasma-RootPath
  * Fix generating the metadata.json file
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sun Nov 20 2016 hrvoje.senjan@gmail.com
- Hotfix 5.28.1
  * Keep installing metadata.desktop (kde#372594)
- Drop upstreamed 0001-keep-installing-metadata-desktop.patch
* Fri Nov 18 2016 alarrosa@suse.com
- Add 0001-keep-installing-metadata-desktop.patch to keep installing
  metadata.desktop (kde#372594)
* Sun Nov  6 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Make sure we're looking both for json and desktop metadata
  * Guard against Q_GLOBAL_STATIC being destroyed at app shutdown
  * Fix dangling pointer in KPackageJob (kde#369935)
  * Remove discovery associated to a key when removing a definition
  * Generate the icon into the appstream file
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
- Drop upstreamed fix-package-remove-definition.diff
* Sun Oct  9 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Don't generate appstream files for components that are not in rdn
  * Make kpackage_install_package work with KDE_INSTALL_DIRS_NO_DEPRECATED
  * Remove unused var KPACKAGE_DATA_INSTALL_DIR
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Fri Oct  7 2016 alarrosa@suse.com
- Add fix-package-remove-definition.diff:
  Removes package discoveries too when removing a definition, so
  old data is not kept forever around.
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Silence contentHash deprecation warnings
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Infer the ParentApp from the PackageStructure plugin
  * Let kpackagetool5 generate appstream information for kpackage components
  * Make it possible to load metadata.json file from kpackagetool5
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * After installing a package, load it
  * If the package exists and up to date don't fail
  * Add Package::cryptographicHash(QCryptographicHash::Algorithm)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Let KDocTools stay optional on KPackage
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Avoid finding the same package multiple times from different paths
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Make it possible to provide the metadata in json
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Fri Dec 11 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * kpackagetool can uninstall a package from a package file
  * kpackagetool is now smarter about finding the right servicetype
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Make the subtitles, subtitles ;)
  * kpackagetool: Fix output of non-latin text to stdout
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Guard the structure qpointer access (kde#347231)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * Add a KPackage::findPackages function similar to
    KPluginLoader::findPlugins
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Renamed kpackagetool man to kpackagetool5
  * Fixed installation on case-insensitive filesystems
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Fri Sep 19 2014 hrvoje.senjan@gmail.com
- Activate kpackage-framework package
